bayespy.inference.vmp.nodes.gaussian.GaussianDistribution.compute_message_to_parent
===================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianDistribution.compute_message_to_parent